pub struct FluentLanguageLoader { /* private fields */ }
LanguageLoader implemenation for the fluent localization system. Also provides methods to access localizations which have been loaded.

⚠️ This API requires the following crate features to be activated: fluent-system.

Implementations

Create a new FluentLanguageLoader, which loads messages for the specified domain, and relies on the specified fallback_language for any messages that do not exist for the current language.

The languages associated with each actual loaded language bundle.

Get a localized message referenced by the message_id.

A non-generic version of FluentLanguageLoader::get_args().

A non-generic version of FluentLanguageLoader::get_args() accepting [FluentArgs] instead of a HashMap.

Get a localized message referenced by the message_id, and formatted with the specified args.

Get a localized message referenced by the message_id.

A non-generic version of FluentLanguageLoader::get_lang_args().

A non-generic version of FluentLanguageLoader::get_lang_args() accepting [FluentArgs] instead of a HashMap.

Get a localized message for the given language identifiers, referenced by the message_id and formatted with the specified args.

Returns true if a message with the specified message_id is available in any of the languages currently loaded (including the fallback language).

Run the closure with the message that matches the specified message_id (if it is available in any of the languages currently loaded, including the fallback language). Returns Some of whatever whatever the closure returns, or None if no messages were found matching the message_id.

Runs the provided closure with an iterator over the messages available for the specified language. There may be duplicate messages when they are duplicated in resources applicable to the language. Returns the result of the closure.

Set whether the underlying Fluent logic should insert Unicode Directionality Isolation Marks around placeables.

See [fluent::bundle::FluentBundleBase::set_use_isolating] for more information.

Note: This function will have no effect if LanguageLoader::load_languages has not been called first.

Default: true.

Apply some configuration to each budle in this loader.

Note: This function will have no effect if LanguageLoader::load_languages has not been called first.